# PrepMan: Enter PrepManEndpoint

Note: This document is currently under development. It will contain the following elements.

- description
- example

When ENTRYTYPEs need to be corrected, change the ENTRYTYPE, and run `colrev prep-man` twice (remove the BIB and CSV file before the second run). This will reapply the field requirements for the new ENTRYTYPE. For example, if a record needs to switch from `article` to `inproceedings`, reapplying the field requirements will create the `booktitle` field and indicate that the `journal`, `volume`, and `number` fields are no longer needed.

## Links
